@@ -70,7 +70,7 @@ static ssize_t io_read_mmap (struct io_stream *s, const int dont_move,
 		s->size = file_stat.st_size;
 		s->mem = NULL;
 
-		if (!RANGE(1, s->size, (off_t)SIZE_MAX)) {
+		if (s->size < 1 || (uint64_t)s->size > SIZE_MAX) {
 			logit ("File size unsuitable for mmap()");
 			return -1;
 		}
@@ -152,8 +152,6 @@ static ssize_t io_internal_read (struct io_stream *s, const int dont_move,
 #ifdef HAVE_MMAP
 static off_t io_seek_mmap (struct io_stream *s, const off_t where)
 {
-	assert (LIMIT(where, s->size));
-
 	return (s->mem_pos = where);
 }
 #endif
@@ -216,21 +214,20 @@ off_t io_seek (struct io_stream *s, off_t offset, int whence)
 	LOCK (s->io_mutex);
 	switch (whence) {
 		case SEEK_SET:
-			if (LIMIT(offset, s->size))
-				new_pos = offset;
+			new_pos = offset;
 			break;
 		case SEEK_CUR:
-			if (LIMIT(s->pos + offset, s->size))
-				new_pos = s->pos + offset;
+			new_pos = s->pos + offset;
 			break;
 		case SEEK_END:
-			if (offset == 0 || LIMIT(s->size + offset, s->size))
-				new_pos = s->size + offset;
+			new_pos = s->size + offset;
 			break;
 		default:
 			fatal ("Bad whence value: %d", whence);
 	}
 
+	new_pos = CLAMP(0, new_pos, s->size);
+
 	if (s->buffered)
 		res = io_seek_buffered (s, new_pos);
 	else
@@ -455,7 +452,8 @@ static void io_open_file (struct io_stream *s, const char *file)
 		s->size = file_stat.st_size;
 
 #ifdef HAVE_MMAP
-		if (options_get_int ("UseMMap") && RANGE(1, s->size, (off_t)SIZE_MAX)) {
+		if (options_get_int ("UseMMap") &&
+		    s->size > 0 && (uint64_t)s->size <= SIZE_MAX) {
 			s->mem = mmap (0, (size_t)s->size, PROT_READ, MAP_SHARED, s->fd, 0);
 			if (s->mem == MAP_FAILED) {
 				s->mem = NULL;
